import React, {Component} from 'react';
import {BlogNews} from "../../../models/BlogNews";
import {NavLink, RouteComponentProps, withRouter} from "react-router-dom";
import axios from "axios";
import {ApiResult} from "../../../models/ApiResult";
import {BlogNewsDetail} from "../../../models/BlogNewsDetail";
import Loading from "../../Shared/Loading";
import ErrorTip from "../../Shared/ErrorTip";

interface PageProps {//可以继承其它的接口类型
    page: number;
    BlogNews: BlogNews[]
}

class AdminPosts extends Component<RouteComponentProps<any, any, PageProps>, any> {

    state = {
        Limit: 15,
        TotalPage: 0,
        blogNews: this.props.location.state.BlogNews
    }

    componentDidMount() {
        let {page} = this.props.location.state;

        page = page === null ? 1 : page;

        this.RenderPage(page);
    }

    RenderPage(page: number) {
        const {Limit} = this.state;
        const token = localStorage.getItem('token');

        const config = {
            headers: {Authorization: `Bearer ${token}`}
        }

        axios.get<{ data: ApiResult<Array<BlogNews>> }>(`http://localhost:5000/api/BlogNews/GetBlogNewsPage?page=${page}&size=${Limit}`, config)
            .then((result) => {

                const {Limit} = this.state;

                if (result.data.Status !== '200') {
                    this.props.history.push('/');
                } else {
                    this.setState({
                        blogNews: result.data.Data,
                        TotalPage: Math.ceil(result.data.Data.length / Limit)
                    })
                }

            })
            .catch()
    }

    DeleteAsync(id: number) {
        let {page} = this.props.location.state;

        if (confirm("💥💢真的要干掉这篇该死的文章吗💢💥")) {
            axios.delete<{ data: ApiResult<BlogNewsDetail> }>(`http://localhost:5000/api/BlogNews/Delete?id=${id}`)
                .then((result) => {
                    if (result.data.Status === '200') {
                        this.RenderPage(page)
                    }
                })
        }
    }

    renderPost(blogNews: BlogNews[], TotalPage: number) {
        const {page} = this.props.location.state;

        const dom = []

        for (let i = 1; i <= TotalPage; i++) {
            let _page = i;

            if (_page == page) {
                dom.push(<span className="page-number current">${_page}</span>);
            } else {
                dom.push(<a className="page-number" onClick={() => this.RenderPage(_page)}
                            href={`/admin/posts/${_page}`}>${_page}</a>);
            }
        }

        return (
            <React.Fragment>
                {this.renderPostPart(blogNews)}
                <nav className="pagination">
                    {dom}
                </nav>
            </React.Fragment>
        );
    }

    renderPostPart(blogNews: BlogNews[]) {
        if (blogNews.length === 0) {
            return (
                <ErrorTip/>
            )
        } else {
            return (
                blogNews.map((blog) => {
                    return (
                        <React.Fragment key={blog.Id}>
                            <h3>{blog.Year}</h3>

                            {blog.BlogNewsList.map((list) => {
                                return (
                                    <article className="archive-item" key={list.Id}>
                                        <NavLink to="#" onClick={() => this.DeleteAsync(list.Id)}>❌</NavLink>
                                        <NavLink to="#"
                                                 onClick={() => this.props.history.push(`/admin/post/${list.Id}`)}>📝</NavLink>
                                        <NavLink to={`/post/${list.Id}`} target="_blank"
                                                 className="archive-item-link">{list.Title}</NavLink>
                                        <span className="archive-item-date">{list.CreateTime}</span>
                                    </article>
                                )
                            })}
                        </React.Fragment>
                    )
                })
            )
        }
    }

    render() {
        const {blogNews, TotalPage} = this.state;

        if (blogNews === null) {
            return (
                <Loading/>
            )
        } else {
            return (
                <div className="post-wrap archive">
                    <NavLink to="/admin/post" style={{float: "right"}}><h3>📝~~~ 新增文章 ~~~📝</h3></NavLink>
                    {this.renderPost(blogNews, TotalPage)}
                </div>
            );
        }
    }
}

export default withRouter(AdminPosts);