import {Component} from 'react';
import Loading from "../../Shared/Loading";
import {Link, RouteComponentProps} from 'react-router-dom';
import axios from 'axios';
import {ApiResult} from '../../../models/ApiResult';
import {BlogNewsDetail} from '../../../models/BlogNewsDetail';
import MDEditor from '@uiw/react-md-editor';

interface IdProps {//可以继承其它的接口类型
    id: number;
    blogNewsDetail: BlogNewsDetail
}

class Post extends Component<RouteComponentProps<any, any, IdProps>, any> {
    state = {
        blogNews: this.props.location.state.blogNewsDetail
    }

    componentDidMount() {
        let {id} = this.props.location.state;

        axios.get<{ data: ApiResult<BlogNewsDetail> }>(`http://localhost:5000/api/BlogNews/GetBlogNewsDetail?id=${id}`)
            .then((result) => {
                if (result.data.Status === '200') {
                    this.setState({blogNews: result.data.Data});
                } else {
                    this.setState({blogNews: {}});
                }
            })
            .catch(() => {
                this.setState({blogNews: null});
            });
    }

    render() {
        const {blogNews} = this.state;

        if (blogNews === null) {
            return (
                <Loading/>
            );
        } else {
            return (
                <div>
                    <article className="post-wrap">
                        <header className="post-header">
                            <h1 className="post-title">{blogNews.Title}</h1>
                            <div className="post-meta">
                                Author:<a rel="author" href="/#">{blogNews.WriterName}</a>
                                <span className="post-time">
                                    Date:<a href="/#">{blogNews.Time}</a>
                                </span>
                            </div>
                        </header>
                        <div className="post-content" id="content">
                            <MDEditor.Markdown source={blogNews.Content}/>
                        </div>
                        <section className="post-copyright">
                            <p className="copyright-item">
                                <span>Author:</span>
                                <span>{blogNews.WriterName}</span>
                            </p>
                            <p className="copyright-item">
                                <span>License:</span>
                                <span>本文采用
                                    <Link target="_blank" to={"http://creativecommons.org/licenses/by-nc-nd/4.0/"}> 知识共享 署名-非商业性使用-禁止演绎(CC BY-NC-ND)国际许可协议 </Link>进行许可
                                </span>
                            </p>
                        </section>
                        <section className="post-tags">
                            <div>
                                <Link to="">back</Link>
                                <span>· </span>
                                <Link to="/">home</Link>
                            </div>
                        </section>
                    </article>
                </div>
            );
        }
    }
}

export default Post;
