import React, {Component} from 'react';
import Loading from "../../Shared/Loading";
import ErrorTip from "../../Shared/ErrorTip";
import {NavLink} from 'react-router-dom';
import {BlogNews} from '../../../models/BlogNews';
import axios from "axios"
import {ApiResult} from "../../../models/ApiResult";

class Posts extends Component {

    componentDidMount() {
        let {page, Limit} = this.state;

        page = 1;

        axios.get<{ data: ApiResult<Array<BlogNews>> }>(`http://localhost:5000/api/BlogNews/GetBlogNewsPage?page=${page}&size=${Limit}`)
            .then((res) => {

                if (res.data.Status === '200') {
                    let blogNews: Array<BlogNews> = res.data.Data;

                    let totalPage = Math.ceil(blogNews.length / Limit);

                    this.setState({
                        TotalPage: totalPage,
                        blogNews: blogNews,
                        page
                    })
                } else {
                    this.setState({
                        blogNews: [],
                    })
                }
            })
            .catch(() => {
                this.setState({
                    blogNews: null,
                })
            });
    }

    state = {
        page: 0,
        Limit: 15,
        TotalPage: 0,
        blogNews: []
    }

    renderPageElement() {
        const {TotalPage, page} = this.state;
        const dom = [];

        for (let i = 1; i <= TotalPage; i++) {
            let _page = i;

            if (page === i)
                dom.push(<span className="page-number current" key={_page}>{_page}</span>)
            else
                dom.push(<a className="page-number" href="/" key={_page}>{_page}</a>)
        }

        return (
            <nav className="pagination">
                {dom}
            </nav>
        )
    }

    renderBlogElement(blogNews: BlogNews[]) {
        if (blogNews !== []) {
            let blogNewsList = blogNews.map(blog => {
                return (<React.Fragment key={blog.Id}>
                        <h3>{blog.Year}</h3>
                        {blog.BlogNewsList.map(list => {
                            return (<article className="archive-item" key={list.Id}>
                                <NavLink to={{
                                    pathname: `/post/${list.Id}`,
                                    state: {id: list.Id, blogNewsDetail: null}
                                }}>{list.Title}</NavLink>
                                <span className="archive-item-date">{list.CreateTime}</span>
                            </article>)
                        })}
                    </React.Fragment>
                )
            })

            return (
                <div className="post-wrap archive">
                    {blogNewsList}
                    <div>
                        {this.renderPageElement()}
                    </div>
                </div>
            )
        } else {
            return (<ErrorTip/>)
        }
    }

    render() {
        const {blogNews} = this.state;

        if (blogNews === null || blogNews.length === 0) {
            return <Loading/>
        } else {
            return (
                <React.Fragment>
                    {
                        this.renderBlogElement(blogNews)
                    }

                </React.Fragment>
            );
        }
    }
}

export default Posts;