import React, {Component} from 'react';
import {NavLink, RouteComponentProps} from "react-router-dom";
import {BlogNews} from "../../../models/BlogNews";
import axios from "axios";
import {ApiResult} from "../../../models/ApiResult";
import Loading from "../../Shared/Loading";
import ErrorTip from "../../Shared/ErrorTip";

interface IdProps {//可以继承其它的接口类型
    id: number;
}

class Writer extends Component<RouteComponentProps<any, any, IdProps>, any> {

    state = {
        writer: '',
        blogNews: Array<BlogNews>()
    }

    componentDidMount() {
        const {id} = this.props.location.state

        axios.get<{ data: ApiResult<Array<BlogNews>> }>(`http://localhost:5000/api/BlogNews/GetBlogNewsByWriterId?id=${id}`)
            .then((result) => {
                if (result.data.Status === '200') {
                    this.setState({
                        writer: result.data.Data.find(x => x)?.Name,
                        blogNews: result.data.Data
                    })
                } else {
                    this.setState({
                        writer: '',
                        blogNews: []
                    })
                }
            })
            .catch(() => {
                this.setState({
                    writer: null,
                    blogNews: null
                })
            })
    }

    renderWriter(blogNews: BlogNews[]) {
        if (blogNews === []) {
            return (
                <ErrorTip/>
            )
        } else {
            return (
                blogNews.map((blog) => {
                    return (
                        <React.Fragment key={blog.Id}>
                            <h3>{blog.Year}</h3>
                            {blog.BlogNewsList.map((list) => {
                                return (
                                    <article className="archive-item" key={list.Id}>
                                        <NavLink to={{
                                            pathname: `/post/${list.Id}`,
                                            state: {id: list.Id, blogNewsDetail: null}
                                        }}>{list.Title}
                                        </NavLink>
                                        <span className="archive-item-date">{list.CreateTime}</span>
                                    </article>
                                )
                            })}
                        </React.Fragment>
                    )
                })
            )
        }
    }

    render() {
        const {blogNews, writer} = this.state;

        if (blogNews === null) {
            <Loading/>
        } else {
            return (
                <React.Fragment>
                    <div className="post-wrap tags">
                        <h2 className="post-title">-&nbsp;Writer&nbsp;·&nbsp;{writer}&nbsp;-</h2>
                    </div>
                    <div className="post-wrap archive">
                        {this.renderWriter(blogNews)}
                    </div>
                </React.Fragment>
            );
        }

    }
}

export default Writer;