import axios from 'axios';
import {Component} from 'react';
import {TypeInfo} from "../../../models/TypeInfo";
import {ApiResult} from "../../../models/ApiResult";
import Loading from "../../Shared/Loading";
import ErrorTip from "../../Shared/ErrorTip";
import {NavLink} from 'react-router-dom';

class Tags extends Component {

    state = {
        tags: Array<TypeInfo>()
    }

    componentDidMount() {
        axios.get<{ data: ApiResult<Array<TypeInfo>> }>(`http://localhost:5000/api/Type/GetTypes`)
            .then((result) => {
                if (result.data.Status === '200') {
                    this.setState({tags: result.data.Data});
                } else {
                    this.setState({tags: []});
                }
            })
            .catch(() => {
                this.setState({tags: null});
            });
    }

    renderTags(tags: TypeInfo[]) {
        if (tags.length === 0) {
            return (
                <ErrorTip/>
            );
        } else {
            return (
                tags.map((tag) => {
                    return (
                        <NavLink key={tag.Id} to={{
                            pathname: `/tag/${tag.Id}`,
                            state: {id: tag.Id}
                        }}>
                            {tag.Name}
                            <small>({tag.Count})</small>
                        </NavLink>
                    )
                })
            );
        }
    }

    render() {

        const {tags} = this.state;

        if (tags === null || tags.length === 0) {
            return (<Loading/>);
        } else {
            return (
                <div className="post-wrap tags">
                    <h2 className="post-title">-&nbsp;Tags&nbsp;-</h2>
                    <div className="tag-cloud-tags">
                        {this.renderTags(tags)}
                    </div>
                </div>
            );
        }
    }


}

export default Tags;