import React, {Component} from 'react';
import {WriterInfo} from "../../../models/WriterInfo";
import axios from "axios";
import {ApiResult} from "../../../models/ApiResult";
import Loading from "../../Shared/Loading";
import ErrorTip from "../../Shared/ErrorTip";
import {NavLink} from 'react-router-dom';

class Writers extends Component {

    state = {
        writers: []
    }

    componentDidMount() {
        axios.get<{ data: ApiResult<Array<WriterInfo>> }>(`http://localhost:5000/api/WriterInfo/GetAllWriters`)
            .then((res) => {
                if (res.data.Status === '200') {
                    this.setState({writers: res.data.Data});
                } else {
                    this.setState({writers: []})
                }
            })
            .catch(() => {
                this.setState({writers: null})
            });
    }

    renderWriter(writers: WriterInfo[]) {
        if (writers === []) {
            return (<ErrorTip/>);
        } else {
            return (
                writers.map((writerInfo) => {
                    return (
                        <div className="card-item" key={writerInfo.Id}>
                            <div className="categories">
                                <NavLink to={{
                                    pathname: `/writer/${writerInfo.Id}`,
                                    state: {id: writerInfo.Id}
                                }}>
                                    <h3>
                                        <i className="iconfont iconcode" style={{paddingRight: '3px'}}/>
                                        {writerInfo.Name}
                                    </h3>
                                    <small>({writerInfo.Count})</small>
                                </NavLink>
                            </div>
                        </div>
                    );
                })
            );
        }
    }

    render() {
        const {writers} = this.state;

        if (writers === null || writers.length === 0) {
            return (
                <Loading/>
            );
        } else {
            return (
                <div className="post-wrap categories">
                    <h2 className="post-title">-&nbsp;Writers&nbsp;-</h2>
                    <div className="categories-card">
                        {this.renderWriter(writers)}
                    </div>
                </div>
            );
        }
    }
}

export default Writers;