import React, {Component} from 'react';
import {RefreshToken} from "../../models/RefreshToken";
import axios from "axios";
import {ApiResult} from "../../models/ApiResult";
import {AuthResult} from "../../models/AuthResult";
import {RouteComponentProps, withRouter} from 'react-router-dom'
import Loading from "./Loading";

class AdminLayout extends Component<RouteComponentProps> {

    state = {
        isLogin: false,
    }

    componentDidMount() {

        let token = JSON.parse(localStorage.getItem('token') || '{}');
        let refresh_token = JSON.parse(localStorage.getItem('refresh_token') || '{}');

        if (!(token || refresh_token)) {
            this.setState({isLogin: true})

            let refreshToken: RefreshToken = {
                Token: token,
                RefreshToken: refresh_token,
            }

            axios.post<{ data: ApiResult<AuthResult> }>(`http://localhost:5000/api/Authorize/RefreshToken`, refreshToken)
                .then((result) => {
                    if (result.data.Status === '200') {
                        if (result.data.Data.Success) {
                            localStorage.setItem('token', result.data.Data.Token);
                            localStorage.setItem('refresh_token', result.data.Data.RefreshToken);
                        } else {
                            this.setState({isLogin: false})

                            this.props.history.push("/login");
                        }
                    } else {
                        console.log(result.data.Message);
                    }
                })
                .catch((error) => {
                    console.log(error)
                });
        } else {
            this.setState({isLogin: false})

            this.props.history.push("/login")
        }
    }

    render() {
        const {isLogin} = this.state;

        if (isLogin) {
            return (
                <Loading/>
            )
        } else {
            return (
                <React.Fragment>
                    {this.props.children}
                </React.Fragment>
            );
        }
    }
}

export default withRouter(AdminLayout);